@@ -27,12 +27,17 @@ class TextInputPlugin(FormFieldPlugin):
         """
         Get form field instances.
         """
+        widget_attrs = {
+            'class': theme.form_element_html_class,
+            'placeholder': self.data.placeholder,
+        }
+
         kwargs = {
             'label': self.data.label,
             'help_text': self.data.help_text,
             'initial': self.data.initial,
             'required': self.data.required,
-            'widget': TextInput(attrs={'class': theme.form_element_html_class}),
+            'widget': TextInput(attrs=widget_attrs),
         }
         if self.data.max_length:
             kwargs['max_length'] = self.data.max_length
